==> delegate6.1.18.tar.gz: delegate6.1.18/resolvy/hostent.c <==
/*////////////////////////////////////////////////////////////////////////
Copyright (c) 1995 Electrotechnical Laboratry (ETL), AIST, MITI

Permission to use, copy, modify, and distribute this material for any
purpose and without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies, and
that the name of ETL not be used in advertising or publicity pertaining
to this material without the specific, prior written permission of an
authorized representative of ETL.
ETL MAKES NO REPRESENTATIONS ABOUT THE ACCURACY OR SUITABILITY OF THIS
MATERIAL FOR ANY PURPOSE.  IT IS PROVIDED "AS IS", WITHOUT ANY EXPRESS
OR IMPLIED WARRANTIES.
/////////////////////////////////////////////////////////////////////////
Content-Type:	program/C; charset=US-ASCII
Program:	hostent.c
Author:		Yutaka Sato <ysato@etl.go.jp>
Description:
History:
	950822	created
//////////////////////////////////////////////////////////////////////#*/

#include "ysocket.h"
static int dummy; /* to avoid empty symbol table */

#ifndef STD_HOSTENT
int h_errno;

sethostent(stayopen)
{
	return RES_sethostent(stayopen);
}
endhostent()
{
	return RES_endhostent();
}
extern void *RES_gethostent();
void *gethostent()
{
	return RES_gethostent();
}
#endif

#ifndef gethostbyname
extern void *RES_gethostbyname();
void *gethostbyname(name)
	char *name;
{
	return RES_gethostbyname(name);
}
#endif

#ifndef gethostbyaddr
extern void *RES_gethostbyaddr();
void *gethostbyaddr(addr,len,type)
	char *addr;
{
	return RES_gethostbyaddr(addr,len,type);
}
#endif

==> delegate9.0.3-pre15.tar.gz: delegate9.0.3-pre15/resolvy/hostent.c <==
/*////////////////////////////////////////////////////////////////////////
Copyright (c) 1995 Electrotechnical Laboratry (ETL), AIST, MITI

Permission to use, copy, modify, and distribute this material for any
purpose and without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies, and
that the name of ETL not be used in advertising or publicity pertaining
to this material without the specific, prior written permission of an
authorized representative of ETL.
ETL MAKES NO REPRESENTATIONS ABOUT THE ACCURACY OR SUITABILITY OF THIS
MATERIAL FOR ANY PURPOSE.  IT IS PROVIDED "AS IS", WITHOUT ANY EXPRESS
OR IMPLIED WARRANTIES.
/////////////////////////////////////////////////////////////////////////
Content-Type:	program/C; charset=US-ASCII
Program:	hostent.c
Author:		Yutaka Sato <ysato@etl.go.jp>
Description:
History:
	950822	created
//////////////////////////////////////////////////////////////////////#*/

#include "vsocket.h"
static int dummy; /* to avoid empty symbol table */

#ifndef STD_HOSTENT
int h_errno;

sethostent(stayopen)
{
	return RES_sethostent(stayopen);
}
endhostent()
{
	return RES_endhostent();
}
extern void *RES_gethostent();
void *gethostent()
{
	return RES_gethostent();
}
#endif

#ifndef gethostbyname
extern void *RES_gethostbyname();
void *gethostbyname(char *name)
{
	return RES_gethostbyname(name);
}
#endif

#ifndef gethostbyaddr
extern void *RES_gethostbyaddr();
void *gethostbyaddr(char *addr,int len,int type)
{
	return RES_gethostbyaddr(addr,len,type);
}
#endif
